@@ -234,14 +234,19 @@ wClientConfigure(WWindow *wwin, XConfigureRequestEvent *xcre)
 
     if (!wwin->flags.shaded) {
         /* If the window is shaded, wrong height will be set for the window */
-        if (xcre->value_mask & CWX)
-            nx = xcre->x - FRAME_BORDER_WIDTH;
+        if (xcre->value_mask & CWX) {
+            nx = xcre->x;
+	    if (!WFLAGP(wwin, no_border))
+	      nx -= FRAME_BORDER_WIDTH;
+	}
         else
             nx = wwin->frame_x;
 
-        if (xcre->value_mask & CWY)
-            ny = xcre->y - ((ofs_y < 0) ? 0 : wwin->frame->top_width)
-		- FRAME_BORDER_WIDTH;
+        if (xcre->value_mask & CWY) {
+            ny = xcre->y - ((ofs_y < 0) ? 0 : wwin->frame->top_width);
+	    if (!WFLAGP(wwin, no_border))
+	      ny -= FRAME_BORDER_WIDTH;
+	}
         else
             ny = wwin->frame_y;
 
@@ -292,6 +297,8 @@ wClientKill(WWindow *wwin)
     XFlush(dpy);
 }
 
+
+
 /*
  *---------------------------------------------------------------------- 
  * wClientCheckProperty--
@@ -302,7 +309,7 @@ wClientKill(WWindow *wwin)
  * Side effects:
  * 	Depends on the changed property.
  * 
- * TODO: CLIENT_LEADER, _GNUSTEP_WM_ATTR
+ * TODO: _GNUSTEP_WM_ATTR
  *---------------------------------------------------------------------- 
  */
 void
@@ -311,31 +318,20 @@ wClientCheckProperty(WWindow *wwin, XPropertyEvent *event)
     XWindowAttributes attribs;
     XWMHints *new_hints;
     int i, g1, g2;
-    char *tmp;
+    char *tmp = NULL;
     
     switch (event->atom) {
      case XA_WM_NAME:
 	/* window title was changed */
-	if (wwin->frame) {
-	    if (!wFetchName(dpy, wwin->client_win, &tmp)) {
-		/* the hint was removed */
-		tmp = wstrdup(DEF_WINDOW_TITLE);
-#ifdef KWM_HINTS
-		wKWMSendEventMessage(wwin, WKWMChangedClient);
-#endif
-	    }
-            if (wFrameWindowChangeTitle(wwin->frame, tmp)) {
-                /* only update the menu if the title has actually changed */
-                UpdateSwitchMenu(wwin->screen_ptr, wwin, ACTION_CHANGE);
-#ifdef KWM_HINTS
-		wKWMSendEventMessage(wwin, WKWMChangedClient);
-#endif
-            }
-	    if (tmp)
-		free(tmp);
+	if (!wFetchName(dpy, wwin->client_win, &tmp)) {
+	    wWindowUpdateName(wwin, NULL);
+	} else {
+	    wWindowUpdateName(wwin, tmp);
 	}
+	if (tmp)
+	    XFree(tmp);	
 	break;
-
+	
      case XA_WM_ICON_NAME:
 #ifdef KWM_HINTS
 	wKWMSendEventMessage(wwin, WKWMChangedClient);
@@ -350,28 +346,29 @@ wClientCheckProperty(WWindow *wwin, XPropertyEvent *event)
 	    wIconChangeTitle(wwin->icon, new_title);
 	}
 	break;
-	
+
      case XA_WM_COMMAND:
 	if (wwin->main_window!=None) {
 	    WApplication *wapp = wApplicationOf(wwin->main_window);
 	    char **argv;
 	    int argc;
 
-	    if (wapp && wapp->app_icon) {
-		if (wapp->app_icon->command!=NULL)
-		    free(wapp->app_icon->command);
+            if (!wapp || !wapp->app_icon)
+		break;
 
-		if (XGetCommand(dpy, wwin->main_window, &argv, &argc)) {
-		    if (argc > 0 && argv != NULL)
-			wapp->app_icon->command = FlattenStringList(argv,argc);
-		    if (argv) {
-			XFreeStringList(argv);
-		    }
+	    if (XGetCommand(dpy, wwin->main_window, &argv, &argc)) {
+		if (argc > 0 && argv != NULL) {
+		    if (wapp->app_icon->command)
+		        wfree(wapp->app_icon->command);
+		    wapp->app_icon->command = wtokenjoin(argv, argc);
+		}
+		if (argv) {
+		    XFreeStringList(argv);
 		}
 	    }
 	}
 	break;
-	
+
      case XA_WM_HINTS:
 	/* WM_HINTS */
 
@@ -491,7 +488,7 @@ wClientCheckProperty(WWindow *wwin, XPropertyEvent *event)
 		|| (wwin->wm_hints->flags & IconWindowHint)) {
 		WApplication *wapp;
 
-		if (wwin->flags.miniaturized) {
+		if (wwin->flags.miniaturized && wwin->icon) {
 		    wIconUpdate(wwin->icon);
 		}
 		wapp = wApplicationOf(wwin->main_window);
@@ -584,7 +581,7 @@ wClientCheckProperty(WWindow *wwin, XPropertyEvent *event)
 
 	    if (wwin->frame)
 		wWindowUpdateButtonImages(wwin);
-	    
+
 	} else if (event->atom==_XA_WM_COLORMAP_WINDOWS) {
 	    
 	    GetColormapWindows(wwin);
@@ -641,8 +638,8 @@ void
 wClientGetNormalHints(WWindow *wwin, XWindowAttributes *wattribs, Bool geometry,
 		      int *x, int *y, unsigned *width, unsigned *height)
 {
-    int pre_icccm=0;
-    
+    int pre_icccm = 0;		       /* not used */
+
     /* find a position for the window */
     if (!wwin->normal_hints)
         wwin->normal_hints = XAllocSizeHints();
@@ -673,6 +670,13 @@ wClientGetNormalHints(WWindow *wwin, XWindowAttributes *wattribs, Bool geometry,
     }
 
     /* some buggy apps set weird hints.. */
+    if (wwin->normal_hints->min_width <= 0) 
+      wwin->normal_hints->min_width = MIN_WINDOW_SIZE;
+    
+    if (wwin->normal_hints->min_height <= 0)
+      wwin->normal_hints->min_height = MIN_WINDOW_SIZE;
+
+
     if (wwin->normal_hints->max_width < wwin->normal_hints->min_width)
 	wwin->normal_hints->max_width = wwin->normal_hints->min_width;
 
@@ -701,12 +705,6 @@ wClientGetNormalHints(WWindow *wwin, XWindowAttributes *wattribs, Bool geometry,
 	    wwin->normal_hints->max_aspect.y = 1;
     }
     
-    if (wwin->normal_hints->min_width <= 0) 
-      wwin->normal_hints->min_width = MIN_WINDOW_SIZE;
-    
-    if (wwin->normal_hints->min_height <= 0)
-      wwin->normal_hints->min_height = MIN_WINDOW_SIZE;
-
     if (wwin->normal_hints->min_height > wwin->normal_hints->max_height) {
 	wwin->normal_hints->min_height = wwin->normal_hints->max_height;
     }
@@ -714,14 +712,11 @@ wClientGetNormalHints(WWindow *wwin, XWindowAttributes *wattribs, Bool geometry,
 	wwin->normal_hints->min_width = wwin->normal_hints->max_width;
     }
 
-    /* pre ICCCM (old) client */
-    if (pre_icccm && !wwin->screen_ptr->flags.startup && geometry) {
-#ifdef DEBUG
-	printf("PRE ICCCM\n");	
-#endif	
 #ifdef IGNORE_PPOSITION
-	wwin->normal_hints->flags &= ~PPosition;
+    wwin->normal_hints->flags &= ~PPosition;
 #endif
+
+    if (pre_icccm && !wwin->screen_ptr->flags.startup && geometry) {
 	if (wwin->normal_hints->flags & (USPosition|PPosition)) {
 	    *x = wwin->normal_hints->x;
 	    *y = wwin->normal_hints->y;
@@ -737,10 +732,11 @@ wClientGetNormalHints(WWindow *wwin, XWindowAttributes *wattribs, Bool geometry,
 void 
 GetColormapWindows(WWindow *wwin)
 {
+#ifndef NO_CRASHES
     if (wwin->cmap_windows) {
 	XFree(wwin->cmap_windows);
     }
-
+    
     wwin->cmap_windows = NULL;
     wwin->cmap_window_no = 0;
 
@@ -750,4 +746,6 @@ GetColormapWindows(WWindow *wwin)
 	wwin->cmap_window_no = 0;
 	wwin->cmap_windows = NULL;
     }
+
+#endif
 }
