@@ -43,7 +43,10 @@ void SetupEnvironment(WScreen *scr);
 
 void DispatchEvent(XEvent *event);
 
-#ifndef LITE
+#ifdef LITE
+#define UpdateSwitchMenu(a,b,c)
+#else
+void UpdateSwitchMenu(WScreen *scr, WWindow *wwin, int action);
 
 Bool wRootMenuPerformShortcut(XEvent *event);
 
@@ -55,6 +58,8 @@ void OpenSwitchMenu(WScreen *scr, int x, int y, int keyboard);
 
 #endif /* !LITE */
 
+
+
 void OpenWindowMenu(WWindow *wwin, int x, int y, int keyboard);
 
 void OpenMiniwindowMenu(WWindow *wwin, int x, int y);
@@ -63,20 +68,6 @@ void OpenWorkspaceMenu(WScreen *scr, int x, int y);
 
 void CloseWindowMenu(WScreen *scr);
 
-#ifdef LITE
-
-#define UpdateSwitchMenu(a, b, c)
-
-#define UpdateSwitchMenuWorkspace(a, b)
-
-#else /*! LITE */
-
-void UpdateSwitchMenu(WScreen *scr, WWindow *wwin, int action);
-
-void UpdateSwitchMenuWorkspace(WScreen *scr, int workspace);
-
-#endif /* !LITE */
-
 WMagicNumber wAddDeathHandler(pid_t pid, WDeathHandler *callback, void *cdata);
 
 void wColormapInstallForWindow(WScreen *scr, WWindow *wwin);
@@ -120,11 +111,9 @@ char *FindImage(char *paths, char *file);
 
 RImage*wGetImageForWindowName(WScreen *scr, char *winstance, char *wclass);
 
-BOOL StringCompareHook(proplist_t pl1, proplist_t pl2);
-
 int IsEof(FILE * stream);	/* feof that stats pipes */
 
-void ParseWindowName(proplist_t value, char **winstance, char **wclass,
+void ParseWindowName(WMPropList *value, char **winstance, char **wclass,
                      char *where);
 
 void SendHelperMessage(WScreen *scr, char type, int workspace, char *msg);
