@@ -49,7 +49,7 @@
 
 /* How many different types of geometry/position
  display thingies are there? */
-#define NUM_DISPLAYS 4
+#define NUM_DISPLAYS 5
 
 #define LEFT            1
 #define RIGHT           2
@@ -167,7 +167,8 @@ cyclePositionDisplay(WWindow *wwin, int x, int y, int w, int h)
     wPreferences.move_display++;
     wPreferences.move_display %= NUM_DISPLAYS;
 
-    if (wPreferences.move_display == WDIS_NEW) {
+    if (wPreferences.move_display == WDIS_NEW
+	|| wPreferences.move_display == WDIS_NONE) {
 	WMUnmapWidget(scr->gview);
     } else {
 	if (wPreferences.move_display == WDIS_CENTER) {
@@ -188,7 +189,8 @@ mapPositionDisplay(WWindow *wwin, int x, int y, int w, int h)
 {
     WScreen *scr = wwin->screen_ptr;
     
-    if (wPreferences.move_display == WDIS_NEW) {
+    if (wPreferences.move_display == WDIS_NEW
+	|| wPreferences.move_display == WDIS_NONE) {
 	return;
     } else if (wPreferences.move_display == WDIS_CENTER) {
 	moveGeometryDisplayCentered(scr, scr->scr_width / 2,
@@ -268,7 +270,7 @@ showGeometry(WWindow *wwin, int x1, int y1, int x2, int y2, int direction)
 	
 	XDrawSegments(dpy, root, gc, segment, 4);
 	
-	sprintf(num, "%i", (by - ty - wwin->normal_hints->base_height) /
+	snprintf(num, sizeof(num), "%i", (by - ty - wwin->normal_hints->base_height) /
 		wwin->normal_hints->height_inc);
 	fw = WMWidthOfString(scr->info_text_font, num, strlen(num));
 	
@@ -287,7 +289,7 @@ showGeometry(WWindow *wwin, int x1, int y1, int x2, int y2, int direction)
 	    s = 15;
 	}
 	mx = x1 + (x2 - x1)/2;
-	sprintf(num, "%i", (x2 - x1 - wwin->normal_hints->base_width) /
+	snprintf(num, sizeof(num), "%i", (x2 - x1 - wwin->normal_hints->base_width) /
 		wwin->normal_hints->width_inc);
 	fw = WMWidthOfString(scr->info_text_font, num, strlen(num));
 	
@@ -350,7 +352,8 @@ cycleGeometryDisplay(WWindow *wwin, int x, int y, int w, int h, int dir)
     wPreferences.size_display++;
     wPreferences.size_display %= NUM_DISPLAYS;
     
-    if (wPreferences.size_display == WDIS_NEW) {
+    if (wPreferences.size_display == WDIS_NEW
+	|| wPreferences.size_display == WDIS_NONE) {
 	WMUnmapWidget(scr->gview);
     } else {
 	if (wPreferences.size_display == WDIS_CENTER) {
@@ -372,7 +375,8 @@ mapGeometryDisplay(WWindow *wwin, int x, int y, int w, int h)
 {
     WScreen *scr = wwin->screen_ptr;
     
-    if (wPreferences.size_display == WDIS_NEW)
+    if (wPreferences.size_display == WDIS_NEW
+	|| wPreferences.size_display == WDIS_NONE)
 	return;
     
     if (wPreferences.size_display == WDIS_CENTER) {
