@@ -26,7 +26,7 @@
 #include "WindowMaker.h"
 #include <sys/types.h>
 
-#include <proplist.h>
+#include <WINGs/WUtil.h>
 
 #ifdef XINERAMA
 #include <X11/Xinerama.h>
@@ -41,14 +41,14 @@
 #define WTB_PFOCUSED	4
 #define WTB_MENU 6
 
-#ifdef GNOME_STUFF
+
 /* an area of the screen reserved by some window */
 typedef struct WReservedArea {
     WArea area;
     Window window;
     struct WReservedArea *next;
 } WReservedArea;
-#endif
+
 
 
 typedef struct WAppIconChain {
@@ -131,9 +131,7 @@ typedef struct _WScreen {
     int current_workspace;	       /* current workspace number */
 
 
-#ifdef GNOME_STUFF
     WReservedArea *reservedAreas;      /* used to build totalUsableArea */
-#endif
 
     WArea usableArea;		       /* area of the workspace where
 					* we can put windows on, as defined
@@ -266,7 +264,7 @@ typedef struct _WScreen {
     /* state and other informations */
     short cascade_index;	       /* for cascade window placement */
 
-    proplist_t session_state;
+    WMPropList *session_state;
 
     /* for double-click detection */
     Time last_click_time;
@@ -300,6 +298,10 @@ typedef struct _WScreen {
 #ifdef KWM_HINTS
     Window kwm_dock;
 #endif
+    
+#ifdef NET_HINTS
+    struct NetData *netdata;
+#endif
 
     int helper_fd;
     pid_t helper_pid;
@@ -336,11 +338,6 @@ typedef struct _WScreen {
 typedef struct WWorkspaceState {
     int flags;
     int workspace;
-#if 0  /* obsoleted by saving menus position in WMState */
-    int menu_x, menu_y;
-    int smenu_x, smenu_y;
-    int wmenu_x, wmenu_y;
-#endif
 } WWorkspaceState;
 
 
