@@ -294,6 +294,13 @@ handleExitSig(int sig)
     sigprocmask(SIG_UNBLOCK, &sigs, NULL);
 }
 
+/* Dummy signal handler */
+static void
+dummyHandler(int sig)
+{
+}
+
+
 /*
  *----------------------------------------------------------------------
  * handleSig--
@@ -646,9 +653,7 @@ wScreenForRootWindow(Window window)
 	}
     }
 
-    assert("bad_root_window" && 0);
-    
-    return NULL;
+    return wScreenForWindow(window);
 }
 
 
@@ -671,7 +676,7 @@ wScreenSearchForRootWindow(Window window)
 	}
     }
     
-    return NULL;
+    return wScreenForWindow(window);
 }
 
 
@@ -715,12 +720,6 @@ static char *atomNames[] = {
     GNUSTEP_TITLEBAR_STATE
 };
 
-static void
-handle_sigpipe(int signum)
-{
-    if (0) signum=0; /* To avoid a gcc warning */
-    return;
-}
 
 /*
  *----------------------------------------------------------
@@ -853,12 +852,12 @@ StartUp(Bool defaultScreenOnly)
     sigaction(SIGUSR2, &sig_action, NULL);
 
     /* ignore dead pipe */
-    sig_action.sa_handler = &handle_sigpipe;
     /* Because POSIX mandates that only signal with handlers are reset
-       accross an exec*(), we do not want to propagate ignoring SIGPIPEs
-       to children. Hence the dummy handler.
-       Philippe Troin <phil@fifi.org>
-    */
+     * accross an exec*(), we do not want to propagate ignoring SIGPIPEs
+     * to children. Hence the dummy handler.
+     * Philippe Troin <phil@fifi.org>
+     */
+    sig_action.sa_handler = &dummyHandler;
     sig_action.sa_flags = SA_RESTART;
     sigaction(SIGPIPE, &sig_action, NULL);
 
@@ -1124,7 +1123,8 @@ manageAllWindows(WScreen *scr, int crashRecovery)
 
                 wWindowMove(wwin, wwin->frame_x - border,
                             wwin->frame_y - border -
-                            wwin->frame->titlebar->height);
+			    (wwin->frame->titlebar ? 
+                             wwin->frame->titlebar->height : 0));
             }
 	}
     }
