@@ -206,6 +206,8 @@
  */
 #undef WINDOW_BIRTH_ZOOM
 
+#define WINDOW_BIRTH_ZOOM2
+
 /*
  * whether arrow drawing in clip buttons should be gradiented
  */
@@ -281,7 +283,7 @@
 #define DEF_FRAME_COLOR   "white"
 
 
-#ifdef I18N_MB
+#ifdef I18N
 #define DEF_TITLE_FONT "\"-*-*-medium-r-normal--14-*\""
 #define DEF_MENU_TITLE_FONT "\"-*-*-medium-r-normal--14-*\""
 #define DEF_MENU_ENTRY_FONT "\"-*-*-medium-r-normal--14-*\""
@@ -291,7 +293,7 @@
 #define DEF_ADDITONAL_FONT "-*-*-medium-r-normal--12-*"
 
 #define DEF_WORKSPACE_NAME_FONT "\"-*-*-medium-r-normal--24-*\""
-#else /* !I18N_MB */
+#else /* !I18N */
 #define DEF_TITLE_FONT "\"-*-helvetica-bold-r-normal-*-12-*-*-*-*-*-*-*\""
 #define DEF_MENU_TITLE_FONT "\"-*-helvetica-bold-r-normal-*-12-*-*-*-*-*-*-*\""
 #define DEF_MENU_ENTRY_FONT "\"-*-helvetica-medium-r-normal-*-12-*-*-*-*-*-*-*\""
@@ -300,7 +302,7 @@
 #define DEF_INFO_TEXT_FONT "\"-*-helvetica-medium-r-normal-*-12-*-*-*-*-*-*-*\""
 
 #define DEF_WORKSPACE_NAME_FONT "\"-*-lucida-bold-r-*-*-24-*-*-*-*-*-*-*\""
-#endif /* !I18N_MB */
+#endif /* !I18N */
 
 #define HELVETICA10_FONT "-*-helvetica-medium-r-normal-*-10-*-*-*-*-*-*-*"
 
